@@ -1,5 +1,5 @@
 package Net::DNS;
-# $Id: DNS.pm,v 1.57 2003/05/22 21:31:49 ctriv Exp $
+# $Id: DNS.pm,v 1.66 2003/07/29 09:26:51 ctriv Exp $
 
 use strict;
 use vars qw(
@@ -18,7 +18,7 @@ use vars qw(
 );
 
 
-$VERSION = "0.34_03";
+$VERSION = '0.38_02';
 
 use Net::DNS::Resolver;
 use Net::DNS::Packet;
@@ -27,10 +27,6 @@ use Net::DNS::Header;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-use XSLoader;
-
-eval { XSLoader::load __PACKAGE__ };
-
 BEGIN {
 	eval { require Net::DNS::RR::SIG };
 	# $@ will be true if any errors where encountered 
@@ -38,11 +34,12 @@ BEGIN {
 	$DNSSEC = $@ ? 0 : 1;
 }
  
- 
- 
-
+require DynaLoader;
 require Exporter;
-@ISA = qw(Exporter);
+@ISA = qw(Exporter DynaLoader);
+
+eval { __PACKAGE__->bootstrap() };
+
 @EXPORT = qw(mx yxrrset nxrrset yxdomain nxdomain rr_add rr_del);
 
 %typesbyname = (
@@ -91,7 +88,7 @@ require Exporter;
 	"UID"		=> 101,		# non-standard
 	"GID"		=> 102,		# non-standard
 	"UNSPEC"	=> 103,		# non-standard
-	"TKEY"		=> 249,	        # RFC 2930
+	"TKEY"		=> 249,	    # RFC 2930
 	"TSIG"		=> 250,		# RFC 2931
 	"IXFR"		=> 251,		# RFC 1995
 	"AXFR"		=> 252,		# RFC 1035
@@ -138,13 +135,13 @@ require Exporter;
 %rcodesbyval = reverse %rcodesbyname;
 
 
-sub version	{ $VERSION; }
-sub PACKETSZ	{ 512; }
-sub HFIXEDSZ	{  12; }
-sub QFIXEDSZ	{   4; }
-sub RRFIXEDSZ	{  10; }
-sub INT32SZ	{   4; }
-sub INT16SZ	{   2; }
+sub version      { $VERSION; }
+sub PACKETSZ  () { 512; }
+sub HFIXEDSZ  () {  12; }
+sub QFIXEDSZ  () {   4; }
+sub RRFIXEDSZ () {  10; }
+sub INT32SZ   () {   4; }
+sub INT16SZ   () {   2; }
 
 
 
@@ -154,14 +151,11 @@ sub INT16SZ	{   2; }
 #    my @mxes = mx('example.com', 'IN');
 #
 sub mx {
-	# If the first argument is a object, use that as our resolver.
 	my $res = ref $_[0] ? shift : Net::DNS::Resolver->new;
 
-	# assign our arguments, setting class to 'IN' if not set for us.
 	my ($name, $class) = @_;
 	$class ||= 'IN';
 
-	# We return failure unless we get an answer.
 	my $ans = $res->query($name, "MX", $class) || return;
 
 	# This construct is best read backwords.
@@ -179,33 +173,27 @@ sub mx {
 }
 
 sub yxrrset {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "yxrrset");
+	return Net::DNS::RR->new_from_string(shift, "yxrrset");
 }
 
 sub nxrrset {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "nxrrset");
+	return Net::DNS::RR->new_from_string(shift, "nxrrset");
 }
 
 sub yxdomain {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "yxdomain");
+	return Net::DNS::RR->new_from_string(shift, "yxdomain");
 }
 
 sub nxdomain {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "nxdomain");
+	return Net::DNS::RR->new_from_string(shift, "nxdomain");
 }
 
 sub rr_add {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "rr_add");
+	return Net::DNS::RR->new_from_string(shift, "rr_add");
 }
 
 sub rr_del {
-	my $string = shift;
-	return Net::DNS::RR->new_from_string($string, "rr_del");
+	return Net::DNS::RR->new_from_string(shift, "rr_del");
 }
 
 1;
@@ -232,55 +220,62 @@ I<DNS and BIND> (Albitz & Liu) for details.
 
 =head2 Resolver Objects
 
-A resolver object is an instance of the C<Net::DNS::Resolver> class.
-A program can have multiple resolver objects, each maintaining
-its own state information such as the nameservers to be queried, 
-whether recursion is desired, etc.
+A resolver object is an instance of the
+L<Net::DNS::Resolver|Net::DNS::Resolver> class. A program can have
+multiple resolver objects, each maintaining its own state information
+such as the nameservers to be queried, whether recursion is desired,
+etc.
 
 =head2 Packet Objects
 
-C<Net::DNS::Resolver> queries return C<Net::DNS::Packet> objects.  Packet
-objects have five sections:
+L<Net::DNS::Resolver|Net::DNS::Resolver> queries return
+L<Net::DNS::Packet|Net::DNS::Packet> objects.  Packet objects have five
+sections:
 
 =over 3
 
 =item *
 
-The header section, a C<Net::DNS::Header> object.
+The header section, a L<Net::DNS::Header|Net::DNS::Header> object.
 
 =item *
 
-The question section, a list of C<Net::DNS::Question> objects.
+The question section, a list of L<Net::DNS::Question|Net::DNS::Question>
+objects.
 
 =item *
 
-The answer section, a list of C<Net::DNS::RR> objects.
+The answer section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
 
 =item *
 
-The authority section, a list of C<Net::DNS::RR> objects.
+The authority section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
 
 =item *
 
-The additional section, a list of C<Net::DNS::RR> objects.
+The additional section, a list of L<Net::DNS::RR|Net::DNS::RR> objects.
 
 =back
 
-The C<Net::DNS::Update> package is a front-end to C<Net::DNS::Packet>
-for creating packet objects to be used in dynamic updates.
+The L<Net::DNS::Update|Net::DNS::Update> package is a front-end to
+L<Net::DNS::Packet|Net::DNS::Packet> for creating packet objects to be
+used in dynamic updates.
 
 =head2 Header Objects
 
-C<Net::DNS::Header> objects represent the header section of a DNS packet.
+L<Net::DNS::Header|Net::DNS::Header> objects represent the header
+section of a DNS packet.
 
 =head2 Question Objects
 
-C<Net::DNS::Question> objects represent the question section of a DNS packet.
+L<Net::DNS::Question|Net::DNS::Question> objects represent the question
+section of a DNS packet.
 
 =head2 RR Objects
 
-C<Net::DNS::RR> is the base class for DNS resource record (RR) objects in
-the answer, authority, and additional sections of a DNS packet.
+L<Net::DNS::RR|Net::DNS::RR> is the base class for DNS resource record
+(RR) objects in the answer, authority, and additional sections of a DNS
+packet.
 
 Don't assume that RR objects will be of the type you requested -- always
 check an RR object's type before calling any of its methods.
@@ -306,10 +301,10 @@ Returns the version of Net::DNS.
     my $res = Net::DNS::Resolver->new;
     my  @mx = mx($res, "example.com");
 
-Returns a list of C<Net::DNS::RR::MX> objects representing the MX
-records for the specified name; the list will be sorted by preference.
-Returns an empty list if the query failed or no MX records were
-found.
+Returns a list of L<Net::DNS::RR::MX|Net::DNS::RR::MX> objects
+representing the MX records for the specified name; the list will be
+sorted by preference. Returns an empty list if the query failed or no MX
+records were found.
 
 This method does not look up A records -- it only performs MX queries.
 
@@ -433,9 +428,8 @@ dynamic updates.
           next unless $rr->type eq "A";
           print $rr->address, "\n";
       }
-  }
-  else {
-      print "query failed: ", $res->errorstring, "\n";
+  } else {
+      warn "query failed: ", $res->errorstring, "\n";
   }
 
 =head2 Find the nameservers for a domain.
@@ -445,13 +439,12 @@ dynamic updates.
   my $query = $res->query("example.com", "NS");
   
   if ($query) {
-      foreach $rr ($query->answer) {
-          next unless $rr->type eq "NS";
+      foreach $rr (grep { $_->type eq 'NS' } $query->answer) {
           print $rr->nsdname, "\n";
       }
   }
   else {
-      print "query failed: ", $res->errorstring, "\n";
+      warn "query failed: ", $res->errorstring, "\n";
   }
 
 =head2 Find the MX records for a domain.
@@ -465,9 +458,8 @@ dynamic updates.
       foreach $rr (@mx) {
           print $rr->preference, " ", $rr->exchange, "\n";
       }
-  }
-  else {
-      print "can't find MX records for $name: ", $res->errorstring, "\n";
+  } else {
+      warn "Can't find MX records for $name: ", $res->errorstring, "\n";
   }
 
 
@@ -479,8 +471,7 @@ dynamic updates.
   
   if ($query) {
       ($query->answer)[0]->print;
-  }
-  else {
+  } else {
       print "query failed: ", $res->errorstring, "\n";
   }
 
@@ -536,14 +527,13 @@ has arrived.
 	      $sel->remove($sock);
 	      $sock = undef;
       }
-  }
-  else {
-      print "timed out after $timeout seconds\n";
+  } else {
+      warn "timed out after $timeout seconds\n";
   }
 
 =head1 BUGS
 
-C<Net::DNS> is slow.  Real slow.
+C<Net::DNS> is slow.
 
 For other items to be fixed, please see the TODO file included with
 the source distribution.
